@@ -29,7 +29,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '2.11';
+our $VERSION = '2.12';
 
 sub new
 {
@@ -659,6 +659,14 @@ Added the possibility to change the sending phonenumber
 Login and selecting phonenumber reads details about tarifs and packages
 Details about tarif and packages are available through getSubscriptions
 
+=item 2.11
+
+Added "Changes"
+
+=item 2.12
+
+Corrected typo in description
+
 =back
 
 =head1 AUTHOR
